.. _schemas:

Schemas
=======

The RAD schemas:

.. asdf-autoschemas::

    aperture-1.0.0
    basic-1.0.0
    cal_logs-1.0.0
    cal_step-1.0.0
    common-1.0.0
    coordinates-1.0.0
    ephemeris-1.0.0
    exposure_type-1.0.0
    exposure-1.0.0
    guidestar-1.0.0
    guidewindow_modes-1.0.0
    guidewindow-1.0.0
    observation-1.0.0
    photometry-1.0.0
    pixelarea-1.0.0
    pointing-1.0.0
    program-1.0.0
    rad_schema-1.0.0
    ramp_fit_output-1.0.0
    ramp-1.0.0
    ref_file-1.0.0
    target-1.0.0
    variance-1.0.0
    velocity_aberration-1.0.0
    visit-1.0.0
    wfi_detector-1.0.0
    wfi_image-1.0.0
    wfi_mode-1.0.0
    wfi_optical_element-1.0.0
    wfi_science_raw-1.0.0
